@@ -29,7 +29,7 @@ class PTUEventUsersPanel(PluginTemplateExtension):
 
     def right_page(self):
         user = self.context['object']
-        content_type_id = ContentType.objects.get_for_model(model=PTUsers).id
+        content_type_id = ContentType.objects.get_for_model(model=user).id
         PTUEvent_ass = PTUEventAssignment.objects.filter(
             object_id=user.id, content_type=content_type_id)
         PTUEvents = []
@@ -50,7 +50,7 @@ class PTUEventWorkstationPanel(PluginTemplateExtension):
 
     def right_page(self):
         ws = self.context['object']
-        content_type_id = ContentType.objects.get_for_model(model=PTWorkstations).id
+        content_type_id = ContentType.objects.get_for_model(model=ws).id
         PTUEvent_ass = PTUEventAssignment.objects.filter(
             object_id=ws.id, content_type=content_type_id)
         PTUEvents = []
